pub fn command_palette_input_context<H: UiHost>(app: &H) -> InputContextExpand description
Best-effort input context for global command discovery surfaces such as command palettes.
pub fn command_palette_input_context<H: UiHost>(app: &H) -> InputContextBest-effort input context for global command discovery surfaces such as command palettes.