Module pointer_queries

Module pointer_queries 

Functions

primary_pointer_can_hover
Returns whether the primary pointer is expected to support hover-driven affordances.
primary_pointer_is_coarse
Returns whether the primary pointer is expected to be coarse (touch-first).
primary_pointer_type
Returns the most recent committed primary pointer type for the window (ADR 0232).