ColumnOrderState

Type Alias ColumnOrderState 

pub type ColumnOrderState = Vec<Arc<str>>;
TanStack-compatible column order: an ordered list of column ids.

Any columns not present in this list keep their original relative order and are appended to the end.

Aliased Type

pub struct ColumnOrderState { /* private fields */ }