macro_rules! ui_component_chrome_layout_patch_only {
($ty:ty) => { ... };
}Expand description
Implement UiPatchTarget + UiSupports* for a component that supports both chrome and layout
refinements, without implementing rendering glue.
macro_rules! ui_component_chrome_layout_patch_only {
($ty:ty) => { ... };
}Implement UiPatchTarget + UiSupports* for a component that supports both chrome and layout
refinements, without implementing rendering glue.