macro_rules! ui_component_passthrough_patch_only {
($ty:ty) => { ... };
}Expand description
Implement UiPatchTarget for a component that does not accept any UiPatch, without
implementing rendering glue.
macro_rules! ui_component_passthrough_patch_only {
($ty:ty) => { ... };
}Implement UiPatchTarget for a component that does not accept any UiPatch, without
implementing rendering glue.