OverlayRequest

Struct OverlayRequest 

pub struct OverlayRequest {
Show 18 fields pub kind: OverlayKind, pub id: GlobalElementId, pub root_name: Option<String>, pub trigger: Option<GlobalElementId>, pub dismissable_branches: Vec<GlobalElementId>, pub consume_outside_pointer_events: bool, pub disable_outside_pointer_events: bool, pub close_on_window_focus_lost: bool, pub close_on_window_resize: bool, pub open: Option<Model<bool>>, pub on_open_auto_focus: Option<OnOpenAutoFocus>, pub on_close_auto_focus: Option<OnCloseAutoFocus>, pub dismissible_on_dismiss_request: Option<OnDismissRequest>, pub dismissible_on_pointer_move: Option<OnDismissiblePointerMove>, pub presence: OverlayPresence, pub initial_focus: Option<GlobalElementId>, pub children: Vec<AnyElement>, pub toast_layer: Option<ToastLayerSpec>,
}

Fields

kind: OverlayKindid: GlobalElementIdroot_name: Option<String>trigger: Option<GlobalElementId>dismissable_branches: Vec<GlobalElementId>

Extra subtrees that should be treated as “inside” for DismissableLayer-style dismissal.

This is used to align Radix DismissableLayerBranch outcomes across disjoint subtrees.

consume_outside_pointer_events: bool

When an outside-press observer is dispatched for this overlay, suppress normal hit-tested pointer-down dispatch to underlay widgets for the same event.

disable_outside_pointer_events: bool

When true, pointer events outside the overlay subtree should not reach underlay widgets while the overlay is open (Radix disableOutsidePointerEvents outcome).

close_on_window_focus_lost: bool

Whether this overlay should close when the OS window loses focus.

close_on_window_resize: bool

Whether this overlay should close when the OS window is resized (or scale factor changes).

open: Option<Model<bool>>on_open_auto_focus: Option<OnOpenAutoFocus>on_close_auto_focus: Option<OnCloseAutoFocus>dismissible_on_dismiss_request: Option<OnDismissRequest>dismissible_on_pointer_move: Option<OnDismissiblePointerMove>presence: OverlayPresenceinitial_focus: Option<GlobalElementId>children: Vec<AnyElement>toast_layer: Option<ToastLayerSpec>

Implementations

Source

impl OverlayRequest

pub fn dismissible_popover( id: GlobalElementId, trigger: GlobalElementId, open: Model<bool>, presence: OverlayPresence, children: Vec<AnyElement>, ) -> Self

pub fn dismissible_menu( id: GlobalElementId, trigger: GlobalElementId, open: Model<bool>, presence: OverlayPresence, children: Vec<AnyElement>, ) -> Self

Dismissible overlay with non-click-through outside press behavior.

This matches Radix-aligned “menu-like” overlays where an outside click closes the overlay without activating the underlay (ADR 0069).

pub fn modal( id: GlobalElementId, trigger: Option<GlobalElementId>, open: Model<bool>, presence: OverlayPresence, children: Vec<AnyElement>, ) -> Self

pub fn tooltip( id: GlobalElementId, open: Model<bool>, presence: OverlayPresence, children: Vec<AnyElement>, ) -> Self

pub fn hover( id: GlobalElementId, trigger: GlobalElementId, open: Model<bool>, presence: OverlayPresence, children: impl IntoIterator<Item = AnyElement>, ) -> Self

pub fn toast_layer(id: GlobalElementId, store: Model<ToastStore>) -> Self

pub fn close_on_window_focus_lost(self, close: bool) -> Self

pub fn close_on_window_resize(self, close: bool) -> Self

pub fn toast_position(self, position: ToastPosition) -> Self

pub fn toast_toaster_id(self, id: impl Into<Arc<str>>) -> Self

pub fn toast_visible_toasts(self, visible_toasts: usize) -> Self

pub fn toast_expand_by_default(self, expand: bool) -> Self

pub fn toast_rich_colors(self, rich_colors: bool) -> Self

pub fn toast_invert(self, invert: bool) -> Self

pub fn toast_container_aria_label(self, label: impl Into<Arc<str>>) -> Self

pub fn toast_container_aria_label_opt(self, label: Option<Arc<str>>) -> Self

pub fn toast_custom_aria_label_opt(self, label: Option<Arc<str>>) -> Self

pub fn toast_offset(self, offset: ToastOffset) -> Self

pub fn toast_offset_opt(self, offset: Option<ToastOffset>) -> Self

pub fn toast_mobile_offset(self, offset: ToastOffset) -> Self

pub fn toast_mobile_offset_opt(self, offset: Option<ToastOffset>) -> Self

pub fn toast_style(self, style: ToastLayerStyle) -> Self

pub fn toast_margin(self, margin: Px) -> Self

pub fn toast_gap(self, gap: Px) -> Self

pub fn toast_min_width(self, width: Px) -> Self

pub fn toast_max_width(self, width: Px) -> Self

pub fn dismissable_branches( self, branches: impl IntoIterator<Item = GlobalElementId>, ) -> Self

pub fn add_dismissable_branch(self, branch: GlobalElementId) -> Self

pub fn extend_dismissable_branches( self, branches: impl IntoIterator<Item = GlobalElementId>, ) -> Self

pub fn consume_outside_pointer_events(self, consume: bool) -> Self

pub fn disable_outside_pointer_events(self, disable: bool) -> Self