ShiftOptions

Struct ShiftOptions 

pub struct ShiftOptions {
    pub main_axis: bool,
    pub cross_axis: bool,
}
Shift configuration inspired by Floating UI’s shift() middleware.

  • main_axis clamps the panel along the placement axis (y for Top/Bottom, x for Left/Right).
  • cross_axis clamps the panel along the alignment axis (x for Top/Bottom, y for Left/Right).

Fields

main_axis: boolcross_axis: bool