SelectItemAlignedElementInputs

Struct SelectItemAlignedElementInputs 

pub struct SelectItemAlignedElementInputs {
Show 20 fields pub direction: LayoutDirection, pub window: Rect, pub trigger: Rect, pub content_min_width: Px, pub content_border_top: Px, pub content_padding_top: Px, pub content_border_bottom: Px, pub content_padding_bottom: Px, pub viewport_padding_top: Px, pub viewport_padding_bottom: Px, pub selected_item_is_first: bool, pub selected_item_is_last: bool, pub value_node: GlobalElementId, pub viewport: GlobalElementId, pub listbox: GlobalElementId, pub content_panel: GlobalElementId, pub scroll_max_offset_y: Option<Px>, pub content_width_probe: Option<GlobalElementId>, pub selected_item: GlobalElementId, pub selected_item_text: GlobalElementId,
}

Fields

direction: LayoutDirectionwindow: Recttrigger: Rectcontent_min_width: Px

Minimum content width (matches CSS min-width on the content element).

content_border_top: Pxcontent_padding_top: Pxcontent_border_bottom: Pxcontent_padding_bottom: Pxviewport_padding_top: Pxviewport_padding_bottom: Pxselected_item_is_first: boolselected_item_is_last: boolvalue_node: GlobalElementIdviewport: GlobalElementIdlistbox: GlobalElementIdcontent_panel: GlobalElementIdscroll_max_offset_y: Option<Px>

Optional scroll max offset (Y) for the viewport.

When provided, it is used to derive a stable items_height (viewport.scrollHeight) even when the listbox content element’s bounds are clipped by the scroll viewport.

content_width_probe: Option<GlobalElementId>

Optional probe element that represents the intrinsic content width (e.g. max item label).

When present, the measured width is used as an additional lower bound for the item-aligned solver. This mirrors Radix’s behavior where the content can grow beyond the trigger width when items require more space.

selected_item: GlobalElementIdselected_item_text: GlobalElementId