pub struct SelectItemAlignedInputs {Show 17 fields
pub direction: LayoutDirection,
pub window: Rect,
pub trigger: Rect,
pub content: Rect,
pub value_node: Rect,
pub selected_item_text: Rect,
pub selected_item: Rect,
pub viewport: Rect,
pub content_border_top: Px,
pub content_padding_top: Px,
pub content_border_bottom: Px,
pub content_padding_bottom: Px,
pub viewport_padding_top: Px,
pub viewport_padding_bottom: Px,
pub selected_item_is_first: bool,
pub selected_item_is_last: bool,
pub items_height: Px,
}Fields
direction: LayoutDirectionwindow: Recttrigger: Rectcontent: RectThe last known content panel rect (used to keep width stable across repositioning).
value_node: RectTrigger value node rect (the text node that displays the selected value).
selected_item_text: RectSelected item’s text rect inside the content.
selected_item: RectSelected item (row) rect inside the content.
viewport: RectThe listbox/viewport rect that establishes scroll offsets for items.
content_border_top: Pxcontent_padding_top: Pxcontent_border_bottom: Pxcontent_padding_bottom: Pxviewport_padding_top: Pxviewport_padding_bottom: Pxselected_item_is_first: boolWhether the alignment item is the first selectable item (Radix items[0]).
selected_item_is_last: boolWhether the alignment item is the last selectable item (Radix items[items.length - 1]).
items_height: PxScrollable height of all items (Radix viewport.scrollHeight).