Functions
- primary_
pointer_ can_ hover - Returns whether the primary pointer is expected to support hover-driven affordances.
- primary_
pointer_ is_ coarse - Returns whether the primary pointer is expected to be coarse (touch-first).
- primary_
pointer_ type - Returns the most recent committed primary pointer type for the window (ADR 0232).