pub struct TanStackSortedFlatRowOrderCache { /* private fields */ }Implementations
Sourceimpl TanStackSortedFlatRowOrderCache
impl TanStackSortedFlatRowOrderCache
pub fn recompute_count(&self) -> u64
pub fn filtered_recompute_count(&self) -> u64
Sourcepub fn sorted_order<'a, TData>(
&mut self,
data: &'a [TData],
columns: &[ColumnDef<TData>],
get_row_key: &dyn Fn(&TData, usize, Option<&RowKey>) -> RowKey,
filter_fns: &HashMap<Arc<str>, FilterFnDef>,
sorting_fns: &HashMap<Arc<str>, SortingFnDef<TData>>,
get_column_can_global_filter: Option<&dyn Fn(&ColumnDef<TData>, &TData) -> bool>,
deps: TanStackSortedFlatRowOrderDeps,
) -> (&Arc<[FlatRowOrderEntry]>, bool)
pub fn sorted_order<'a, TData>( &mut self, data: &'a [TData], columns: &[ColumnDef<TData>], get_row_key: &dyn Fn(&TData, usize, Option<&RowKey>) -> RowKey, filter_fns: &HashMap<Arc<str>, FilterFnDef>, sorting_fns: &HashMap<Arc<str>, SortingFnDef<TData>>, get_column_can_global_filter: Option<&dyn Fn(&ColumnDef<TData>, &TData) -> bool>, deps: TanStackSortedFlatRowOrderDeps, ) -> (&Arc<[FlatRowOrderEntry]>, bool)
Returns a stable, memoized ordering of the root row list after filtering + sorting.
Notes:
- This cache is designed for “rebuild every frame” callers. Keep it outside the ephemeral table instance and feed dependency snapshots.
- Dependency tracking is explicit via
deps. If you change any inputs that are not represented indeps(e.g.filter_fns,sorting_fns, or the closure identities), you must reset the cache (or bump a revision captured indeps).