macro_rules! ui_component_passthrough {
($ty:ty) => { ... };
}Expand description
Implement patch + render glue for a component that does not accept any UiPatch, but still
wants to opt into the .ui() surface (e.g. purely cosmetic elements).
macro_rules! ui_component_passthrough {
($ty:ty) => { ... };
}Implement patch + render glue for a component that does not accept any UiPatch, but still
wants to opt into the .ui() surface (e.g. purely cosmetic elements).