pub fn v_stack<H: UiHost, F, I>(children: F) -> UiBuilder<FlexBox<H, F>>Expand description
Returns a patchable vertical flex layout builder that does not force width: fill.
Use this when you want the column to shrink-wrap its contents (or to avoid inflating child hit boxes due to a fill-width flex root).